@@ -19,11 +19,14 @@
 #include "core/verifier.h"
 #include "core/signature.h"
 
+#ifdef Q_OS_WIN
+#include <sys/utime.h>
+#else
 #include <utime.h>
+#endif
 
 #include "kget_debug.h"
 
-#include <KIconLoader>
 #include <KIO/CopyJob>
 #include <KLocalizedString>
 #include <KMessageBox>
