@@ -25,13 +25,13 @@ class ViewsContainer : public QWidget
     public:
         ViewsContainer(QWidget * parent = nullptr);
 
-    public slots:
+    public Q_SLOTS:
         void showTransferDetails(TransferHandler * transfer);
         void closeTransferDetails(TransferHandler * transfer);
         void selectAll();
 
     private:
-        TransfersView   * m_transfersView;
+        TransfersView   * m_transfersView = nullptr;
 };
 
 #endif
